/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React from 'react';
import classNames from 'classnames';
import supportImg from '../../assets/support-apache.png'
import asfLogo from '../../assets/asf_logo.svg'
import styles from './index.less';

const GlobalFooter = ({ className, links, copyright }) => {
  const imgStyle = classNames(styles.imgStyle, className);
  const clsString = classNames(styles.globalFooter, className);
  return (
    <div className={clsString}>
      {links && (
        <div className={styles.links}>
          {links.map(link => (
            <a key={link.key} target={link.blankTarget ? '_blank' : '_self'} rel="noreferrer" href={link.href}>
              {link.title}
            </a>
          ))}
        </div>
      )}
      <img className={imgStyle} src={supportImg} alt="Apache Support Logo" />
      <img className={imgStyle} src={asfLogo} alt="The Apache Software Foundation" />
      {copyright && <div className={styles.copyright}>{copyright}</div>}
    </div>
  );
};

export default GlobalFooter;
